@@ -8,7 +8,7 @@ from trytond.tools import safe_eval
 from trytond.pyson import If, Eval
 from trytond.transaction import Transaction
 from trytond.pool import Pool
-from trytond.backend import TableHandler
+from trytond import backend
 
 __all__ = ['PriceList', 'PriceListLine']
 
@@ -52,7 +52,7 @@ class PriceList(ModelSQL, ModelView):
     company = fields.Many2One('company.company', 'Company', required=True,
         select=True, domain=[
             ('id', If(Eval('context', {}).contains('company'), '=', '!='),
-                Eval('context', {}).get('company', 0)),
+                Eval('context', {}).get('company', -1)),
             ])
     lines = fields.One2Many('product.price_list.line', 'price_list', 'Lines')
 
@@ -117,9 +117,7 @@ class PriceListLine(ModelSQL, ModelView):
     price_list = fields.Many2One('product.price_list', 'Price List',
             required=True, ondelete='CASCADE')
     product = fields.Many2One('product.product', 'Product')
-    sequence = fields.Integer('Sequence',
-        order_field='(%(table)s.sequence IS NULL) %(order)s, '
-        '%(table)s.sequence %(order)s')
+    sequence = fields.Integer('Sequence')
     quantity = fields.Float('Quantity', digits=(16, Eval('unit_digits', 2)),
             depends=['unit_digits'])
     unit_digits = fields.Function(fields.Integer('Unit Digits',
@@ -140,6 +138,7 @@ class PriceListLine(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
         table = TableHandler(cursor, cls, module_name)
 
@@ -148,6 +147,11 @@ class PriceListLine(ModelSQL, ModelView):
         # Migration from 2.4: drop required on sequence
         table.not_null_action('sequence', action='remove')
 
+    @staticmethod
+    def order_sequence(tables):
+        table, _ = tables[None]
+        return [table.sequence == None, table.sequence]
+
     @staticmethod
     def default_formula():
         return 'unit_price'
@@ -197,7 +201,7 @@ class PriceListLine(ModelSQL, ModelView):
         for field in pattern.keys():
             if field not in self._fields:
                 continue
-            if not getattr(self, field):
+            if getattr(self, field) is None:
                 continue
             if self._fields[field]._type == 'many2one':
                 if getattr(self, field).id != pattern[field]:
